#!/usr/bin/env python3

import click

from miblepy import CONFIG_FILE, MAX_RETRIES, Miblepy, __name__ as mbp_name, __version__ as mbp_version, hl


CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])


@click.group(context_settings=CONTEXT_SETTINGS, invoke_without_command=True)
@click.pass_context
@click.option("--version", default=False, is_flag=True, help=f"show {mbp_name} version")
@click.option("-d", "--debug", default=False, is_flag=True, help="enable debug output")
def cli(ctx: click.Context, version: bool, debug: bool) -> None:
    """fetch data from ble sensors and push it to a mqtt broker

      https://github.com/benleb/miblepy
    """

    ctx.ensure_object(dict)
    ctx.obj["debug"] = debug

    if not ctx.invoked_subcommand:

        if version:
            click.echo(f"{mbp_name} {hl(mbp_version)} | https://github.com/benleb/miblepy | @benleb")
            exit(0)

        click.echo(ctx.get_help())


@cli.command()
@click.pass_context
@click.option(
    "-c", "--config", default=CONFIG_FILE, type=click.Path(file_okay=True), required=False, help="path to config file",
)
@click.option(
    "-r", "--retries", default=MAX_RETRIES, type=int, help="times we try to get data from a sensor",
)
def fetch(ctx: click.Context, config: str, retries: int) -> None:
    Miblepy(config_file_path=config, retries=retries, debug=ctx.obj["debug"]).go()


if __name__ == "__main__":
    cli(obj={})



# -*- coding: utf-8 -*-

# DO NOT EDIT THIS FILE!
# This file has been autogenerated by dephell <3
# https://github.com/dephell/dephell

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

readme = ''

setup(
    long_description=readme,
    name='miblepy',
    version='0.3.0',
    description='miblepy fetches data from various (Xiaomi/Mijia/Mi) Bluetooth LE devices and push it to a MQTT broker in a coordinated, sequential manner.',
    python_requires='==3.*,>=3.8.0',
    author='Ben Lebherz',
    author_email='git@benleb.de',
    classifiers=[
        'Intended Audience :: Developers', 'Programming Language :: Python :: 3'
    ],
    entry_points={"console_scripts": ["mible = miblepy.cli:cli"]},
    packages=['miblepy', 'miblepy.devices.xbm'],
    package_dir={"": "."},
    package_data={},
    install_requires=[
        'bluepy==1.*,>=1.3.0', 'btlewrap==0.0.8', 'click==7.*,>=7.1.2',
        'miflora==0.*,>=0.6.0', 'paho-mqtt==1.*,>=1.5.0', 'tomlkit==0.*,>=0.6.0'
    ],
    extras_require={
        "dev": [
            "bandit==1.*,>=1.6.2", "black==19.*,>=19.10.0.b0",
            "flake8==3.*,>=3.8.1", "isort==4.*,>=4.3.21", "mypy==0.*,>=0.770.0",
            "pycodestyle==2.*,>=2.6.0", "pytest==5.*,>=5.2.0"
        ]
    },
)
